@@ -1,37 +1,33 @@
 /****************************************************************************
 **
-** This file is part of the KD Soap library.
+** This file is part of the KD Soap project.
 **
-** SPDX-FileCopyrightText: 2010-2021 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+** SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 **
-** SPDX-License-Identifier: LicenseRef-KDAB-KDSoap-AGPL3-Modified OR LicenseRef-KDAB-KDSoap OR LicenseRef-KDAB-KDSoap-US
-**
-** Licensees holding valid commercial KD Soap licenses may use this file in
-** accordance with the KD Soap Commercial License Agreement provided with
-** the Software.
-**
-** Contact info@kdab.com if any conditions of this licensing are not clear to you.
+** SPDX-License-Identifier: MIT
 **
 ****************************************************************************/
+#include "KDSoapServer.h"
+#include "KDSoapServerAuthInterface.h"
+#include "KDSoapServerCustomVerbRequestInterface.h"
+#include "KDSoapServerObjectInterface.h"
+#include "KDSoapServerRawXMLInterface.h"
 #include "KDSoapServerSocket_p.h"
 #include "KDSoapSocketList_p.h"
-#include "KDSoapServerObjectInterface.h"
-#include "KDSoapServerAuthInterface.h"
-#include "KDSoapServerRawXMLInterface.h"
-#include "KDSoapServerCustomVerbRequestInterface.h"
-#include "KDSoapServer.h"
 #include <KDSoapClient/KDSoapMessage.h>
-#include <KDSoapClient/KDSoapNamespaceManager.h>
 #include <KDSoapClient/KDSoapMessageReader_p.h>
 #include <KDSoapClient/KDSoapMessageWriter_p.h>
+#include <KDSoapClient/KDSoapNamespaceManager.h>
 #include <QBuffer>
-#include <QThread>
-#include <QMetaMethod>
-#include <QFile>
 #include <QDir>
+#include <QFile>
 #include <QFileInfo>
+#include <QMetaMethod>
+#include <QThread>
 #include <QVarLengthArray>
 
+static const char s_forbidden[] = "HTTP/1.1 403 Forbidden\r\nContent-Length: 0\r\n\r\n";
+
 KDSoapServerSocket::KDSoapServerSocket(KDSoapSocketList *owner, QObject *serverObject)
 #ifndef QT_NO_SSL
     : QSslSocket()
@@ -50,7 +46,7 @@ KDSoapServerSocket::KDSoapServerSocket(KDSoapSocketList *owner, QObject *serverO
     , m_chunkStart(0)
 {
     connect(this, &QIODevice::readyRead, this, &KDSoapServerSocket::slotReadyRead);
-    m_doDebug = qgetenv("KDSOAP_DEBUG").toInt();
+    m_doDebug = qEnvironmentVariableIsSet("KDSOAP_DEBUG");
 }
 
 // The socket is deleted when it emits disconnected() (see KDSoapSocketList::handleIncomingConnection).
@@ -74,10 +70,21 @@ static HeadersMap parseHeaders(const QByteArray &headerData)
         return headersMap;
     }
     const QByteArray &requestType = firstLine.at(0);
-    const QByteArray path = QDir::cleanPath(QString::fromLatin1(firstLine.at(1).constData())).toLatin1();
-    const QByteArray &httpVersion = firstLine.at(2);
     headersMap.insert("_requestType", requestType);
-    headersMap.insert("_path", path);
+
+    // Grammar from https://datatracker.ietf.org/doc/html/rfc7230#section-5.3.1
+    //  origin-form    = absolute-path [ "?" query ]
+    // and https://datatracker.ietf.org/doc/html/rfc3986#section-3.3
+    // says the path ends at the first '?' or '#' character
+    const QByteArray arg1 = firstLine.at(1);
+    const int queryPos = arg1.indexOf('?');
+    const QByteArray path = queryPos >= 0 ? arg1.left(queryPos) : arg1;
+    const QByteArray query = queryPos >= 0 ? arg1.mid(queryPos) : QByteArray();
+    // Unfortunately QDir::cleanPath works with QString
+    const QByteArray cleanedPath = QDir::cleanPath(QString::fromUtf8(path)).toUtf8();
+    headersMap.insert("_path", cleanedPath + query);
+
+    const QByteArray &httpVersion = firstLine.at(2);
     headersMap.insert("_httpVersion", httpVersion);
 
     while (!sourceBuffer.atEnd()) {
@@ -275,6 +282,12 @@ void KDSoapServerSocket::handleRequest(const QMap<QByteArray, QByteArray> &httpH
     const QByteArray requestType = httpHeaders.value("_requestType");
     const QString path = QString::fromLatin1(httpHeaders.value("_path").constData());
 
+    if (!path.startsWith(QLatin1String("/"))) {
+        // denied for security reasons (ex: path starting with "..")
+        write(s_forbidden);
+        return;
+    }
+
     KDSoapServerAuthInterface *serverAuthInterface = qobject_cast<KDSoapServerAuthInterface *>(m_serverObject);
     if (serverAuthInterface) {
         const QByteArray authValue = httpHeaders.value("authorization");
@@ -404,8 +417,7 @@ bool KDSoapServerSocket::handleFileDownload(KDSoapServerObjectInterface *serverO
         return true;
     }
     if (!device->open(QIODevice::ReadOnly)) {
-        const QByteArray forbidden = "HTTP/1.1 403 Forbidden\r\nContent-Length: 0\r\n\r\n";
-        write(forbidden);
+        write(s_forbidden);
         delete device;
         return true; // handled!
     }
@@ -417,14 +429,14 @@ bool KDSoapServerSocket::handleFileDownload(KDSoapServerObjectInterface *serverO
     Q_ASSERT(written == response.size()); // Please report a bug if you hit this.
     Q_UNUSED(written);
 
-    char block[4096] = { 0 };
-    qint64 totalRead = 0;
+    char block[4096] = {0};
+    // qint64 totalRead = 0;
     while (!device->atEnd()) {
         const qint64 in = device->read(block, sizeof(block));
         if (in <= 0) {
             break;
         }
-        totalRead += in;
+        // totalRead += in;
         if (in != write(block, in)) {
             // error = true;
             break;
@@ -448,11 +460,13 @@ void KDSoapServerSocket::writeXML(const QByteArray &xmlResponse, bool isFault)
         qDebug() << "KDSoapServerSocket: writing" << httpHeaders << xmlResponse;
     }
     qint64 written = write(httpHeaders);
-    Q_ASSERT(written == httpHeaders.size()); // Please report a bug if you hit this.
+    if (written != httpHeaders.size()) {
+        qWarning() << "Only wrote" << written << "out of" << httpHeaders.size() << "bytes of HTTP headers. Error:" << errorString();
+    }
     written = write(xmlResponse);
-    Q_ASSERT(written == xmlResponse.size()); // Please report a bug if you hit this.
-    Q_UNUSED(written);
-    // flush() ?
+    if (written != xmlResponse.size()) {
+        qWarning() << "Only wrote" << written << "out of" << xmlResponse.size() << "bytes of response. Error:" << errorString();
+    }
 }
 
 void KDSoapServerSocket::sendReply(KDSoapServerObjectInterface *serverObjectInterface, const KDSoapMessage &replyMsg)
@@ -460,7 +474,7 @@ void KDSoapServerSocket::sendReply(KDSoapServerObjectInterface *serverObjectInte
     const bool isFault = replyMsg.isFault();
 
     QByteArray xmlResponse;
-    if (!replyMsg.isNull()) {
+    if (!replyMsg.isNil()) {
         KDSoapMessageWriter msgWriter;
         // Note that the kdsoap client parsing code doesn't care for the name (except if it's fault), even in
         // Document mode. Other implementations do, though.
